Range-v3: ranges::v3::tag::out1::getter< Untagged, I, Next > Class Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::tag::out1::getter< Untagged, I, Next > Class Template Reference
Inheritance diagram for ranges::v3::tag::out1::getter< Untagged, I, Next >:

## Public Member Functions
| getter (getter &&)=default
template<int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(MoveConstructible< Untagged >()), int >::type = 0>
constexpr | getter (Untagged &&that) noexcept(std::is_nothrow_move_constructible< Untagged >::value)
template<int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(CopyConstructible< Untagged >()), int >::type = 0>
constexpr | getter (Untagged const &that) noexcept(std::is_nothrow_copy_constructible< Untagged >::value)
| getter (getter const &)=default
getter & | operator= (getter &&)=default
getter & | operator= (getter const &)=default
constexpr meta::_t< std::tuple_element< I, Untagged > > const & | out1 () const &noexcept(noexcept( detail::adl_get< I >(std::declval< Untagged const & >())))
meta::_t< std::tuple_element< I, Untagged > > && | out1 ()&&noexcept(noexcept( detail::adl_get< I >(std::declval< Untagged >())))
meta::_t< std::tuple_element< I, Untagged > > & | out1 ()&noexcept(noexcept( detail::adl_get< I >(std::declval< Untagged & >())))